@@ -1,14 +1,14 @@
 import code
+import re
 import sys
 from pathlib import Path
 
-from hello.fiftyone.core import merge_samples
-from hello.utils import importer
-
 import fiftyone as fo
 from fiftyone.utils.labels import (objects_to_segmentations,
                                    segmentations_to_detections)
 
+from hello.fiftyone.core import merge_samples
+
 dataset_doc_str = """\
 tips:
 
@@ -105,7 +105,11 @@ def load_dataset(dataset_dir, info_py="info.py", data_path="data", labels_path="
     }
 
     if info_py.is_file():
-        info.update(importer.load_from_file("info_py", info_py).info)
+        with open(info_py, "r") as f:
+            codestr = f.read()
+
+        _info = eval(re.split(r"info\s*=\s*", codestr)[1])
+        info.update(_info)
 
     suffix = labels_path.suffix
 
